from setuptools import setup, find_packages

setup(
  name='faker-ids',
  version='0.0.6.7',
  description='Fake id generator. Fetches upto 5 MILLION fake details like firstname, lastnam, emailid and mobile number.',
  long_description=open('readme.txt').read(),# + '\n\n' + open('CHANGELOG.txt').read(),
  url='',  
  author='Balaji Betadur',
  author_email='balajibetadur@gmail.com',
  license='MIT', 
#   classifiers=classifiers,
  keywords=['fakeid','indians','indian fake ids','faker','fakes','fake ids','python','fake-ids python','fake indian ids python'],
  packages=['faker_ids'], # find_packages(),
  install_requires=['pandas'] 
) 


import pandas as pd
import json


import os
this_dir, this_filename = os.path.split(__file__)
DATA_PATH = os.path.join(this_dir,"id.csv")
csv = pd.read_csv(DATA_PATH)

# csv = pd.read_csv('id.csv')
csv = csv.values.tolist()


def get_ids(n):
    id = []
    for i in range(n):
        temp = {}
        temp['firstName'] = csv[i][0]
        temp['lastName'] = csv[i][1]
        temp['emailId'] = csv[i][2]
        temp['mobileNumber'] = csv[i][3]
        id.append(temp)
    return json.dumps(id, indent=4, sort_keys=True)
